//
// Created by philipp on 16.05.18.
//

#include <iostream>
#include "../include/PC2CarLib/CommandSender.h"
#include "../include/PC2CarLib/CommandReceiver.h"

template<typename T>
void printDelay(const networking::time::TimePoint & startTime, networking::time::TimedValue<T> value)
{
    auto now = networking::time::now();
    std::cout << "DELAY: " << std::chrono::duration_cast<std::chrono::seconds>(value.getTimestamp() - startTime).count() << "s\n";
}

int main(int argc, char ** argv)
{
    using namespace pc2car;

    networking::Networking net;
    CommandSender sender{net, "127.0.0.1"};
    auto receiver = CommandReceiver::create(net);
    auto startTime = networking::time::now();
    receiver->receiveCommands(
        [&](CommandCode code)
        {
            using namespace commandCodes;
            std::cout << "code: " << code << "\n";
            switch (code)
            {
                case ENABLE_LOGGING:
                    std::cout << "ENABLE_LOGGING\n";
                    std::cout << receiver->isLoggingEnabled().get() << "\n";
                    printDelay(startTime, receiver->isLoggingEnabled());
                    break;

                case ENABLE_PLATOON:
                    std::cout << "ENABLE_PLATOON\n";
                    std::cout << receiver->isPlatoonEnabled().get() << "\n";
                    printDelay(startTime, receiver->isPlatoonEnabled());
                    break;

                case ENABLE_RC_MODE:
                    std::cout << "ENABLE_RC_MODE\n";
                    std::cout << receiver->isRcModeEnabled().get() << "\n";
                    printDelay(startTime, receiver->isRcModeEnabled());
                    break;

                case SET_PS:
                    std::cout << "SET_PS\n";
                    std::cout << receiver->getPlatoonSpeed().get() << "\n";
                    printDelay(startTime, receiver->getPlatoonSpeed());
                    break;

                case SET_IPD:
                    std::cout << "SET_IPD\n";
                    std::cout << receiver->getInnerPlatoonDistance().get() << "\n";
                    printDelay(startTime, receiver->getInnerPlatoonDistance());
                    break;

                case SET_SPEED:
                    std::cout << "SET_SPEED\n";
                    std::cout << receiver->getSpeed().get() << "\n";
                    printDelay(startTime, receiver->getInnerPlatoonDistance());
                    break;
            }
            std::cout << std::flush;
        });

    while (1);
    return 0;
}